@@ -2130,7 +2130,7 @@ sub _dotls {
    }
 
    $self->{_on_starttls}
-      and Net::SSLeay::state ($self->{tls}) == Net::SSLeay::ST_OK ()
+      and Net::SSLeay::state ($self->{tls}) == 1
       and (delete $self->{_on_starttls})->($self, 1, "TLS/SSL connection established");
 }
 
@@ -2224,7 +2224,7 @@ sub starttls {
 #   Net::SSLeay::CTX_set_mode ($ssl,
 #      (eval { local $SIG{__DIE__}; Net::SSLeay::MODE_ENABLE_PARTIAL_WRITE () } || 1)
 #      | (eval { local $SIG{__DIE__}; Net::SSLeay::MODE_ACCEPT_MOVING_WRITE_BUFFER () } || 2));
-   Net::SSLeay::CTX_set_mode ($tls, 1|2);
+   Net::SSLeay::set_mode ($tls, 1|2);
 
    $self->{_rbio} = Net::SSLeay::BIO_new (Net::SSLeay::BIO_s_mem ());
    $self->{_wbio} = Net::SSLeay::BIO_new (Net::SSLeay::BIO_s_mem ());
